@@ -2,7 +2,7 @@
 from __future__ import annotations
 
 import re
-from typing import Iterator, Optional, Tuple
+from typing import Iterator
 
 from pymmcore_plus import CMMCorePlus
 
@@ -10,7 +10,7 @@ MAG_PATTERN = re.compile(r"(\d{1,3})[xX]")
 RESOLUTION_ID_PREFIX = "px_size_"
 
 
-def load_system_config(config: str = "", mmcore: Optional[CMMCorePlus] = None) -> None:
+def load_system_config(config: str = "", mmcore: CMMCorePlus | None = None) -> None:
     """Internal convenience for `loadSystemConfiguration(config)`.
 
     This also unloads all devices first and resets the STATE.
@@ -24,7 +24,7 @@ def load_system_config(config: str = "", mmcore: Optional[CMMCorePlus] = None) -
     mmc.loadSystemConfiguration(config or "MMConfig_demo.cfg")
 
 
-def iter_dev_props(mmc: Optional[CMMCorePlus] = None) -> Iterator[Tuple[str, str]]:
+def iter_dev_props(mmc: CMMCorePlus | None = None) -> Iterator[tuple[str, str]]:
     """Yield all pairs of currently loaded (device_label, property_name)."""
     mmc = mmc or CMMCorePlus.instance()
     for dev in mmc.getLoadedDevices():
